@@ -23,6 +23,9 @@ test_that("Inheritance", {
   expect_equal(tmp$get(), "?!: ")
   expect_equal(tmp$set("s"), "s")
   expect_equal(tmp$get(), "?!: s")
+  
+  removeClass("parent")
+  removeClass("child")
 })
 
 test_that("Replacing fields I", {
@@ -39,7 +42,10 @@ test_that("Replacing fields I", {
   })
     
   tmp <- child()
-  expect_is(tmp$get(), "NULL")
+  expect_equal(tmp$get(), "value")
+  
+  removeClass("parent")
+  removeClass("child")
 })
 
 test_that("Replacing fields II", {
@@ -57,6 +63,8 @@ test_that("Replacing fields II", {
     
   tmp <- child()
   expect_equal(tmp$foo(), 2)
-  expect_equal(tmp$get(), 1)
+  expect_equal(tmp$get(), 2)
+  
+  removeClass("parent")
+  removeClass("child")
 })
-
